#!/usr/bin/env python2
# -*- coding: utf-8 -*-
"""
Created on Wed Mar 28 11:12:51 2018

@author: emanuel
"""

import numpy as np
import matplotlib.pyplot as plt
from matplotlib.collections import PatchCollection,LineCollection
from mpl_toolkits.basemap import Basemap
from matplotlib.patches import PathPatch
from matplotlib.path import Path
   
f = plt.figure(figsize=(10,8))
ax = f.add_subplot(111)
m = Basemap(projection='tmerc',lat_0=45,lon_0=17, llcrnrlat=40.5, urcrnrlat=50.5,
            llcrnrlon=4,urcrnrlon=29, resolution='h',area_thresh=25)

m.drawmapboundary(fill_color='aqua')
m.fillcontinents(color='grey')

m.readshapefile("../shape_files/tect_units_alcapadi","alcapadiunits",drawbounds=False)
patches   = []
colors = []
for i in range(len(m.alcapadiunits)):
    info = m.alcapadiunits_info[i]
    shape = m.alcapadiunits[i] 
    if info["RINGNUM"] == 1:
        pathcoords = np.zeros((0,2))
        pathcommands = []
        if info["tect_unit"] == "Adria accreted":
            colors.append((0.8,0.7,0.45)) #rgb value
        elif info["tect_unit"] == "Adria autochton":
            colors.append((0.52,0.32,0.2))
        elif info["tect_unit"] == "Europe accreted":
            colors.append((0.42,0.67,0.88))
        elif info["tect_unit"] == "flexural foredeep and graben fill":
            colors.append(0.6) # grayscale
        elif info["tect_unit"] == "Alpine Tethys":
            colors.append((0.,0.65,0.3))
        elif info["tect_unit"] == "Neotethys":
            colors.append((0.5,0.8,0.32))
        else:
            colors.append("lightgrey")
    pathcoords = np.vstack((pathcoords,np.array(shape)))
    pathcoords = np.vstack((pathcoords,np.zeros((1,2))))
    path_n = len(shape)*[Path.LINETO]
    path_n[0] = Path.MOVETO
    path_n.append(Path.CLOSEPOLY)
    pathcommands += path_n
    if i+1 == len(m.alcapadiunits):      
        path = Path(pathcoords,pathcommands)
        patch = PathPatch(path)
        patches.append(patch) 
        continue
    if m.alcapadiunits_info[i+1]["RINGNUM"] <= info["RINGNUM"]:
        path = Path(pathcoords,pathcommands)
        patch = PathPatch(path)
        patches.append(patch)
ax.add_collection(PatchCollection(patches, facecolor=colors, edgecolor='white', linewidths=0.1, zorder=2))

m.readshapefile("../shape_files/faults_alcapadi","alcapadifaults",drawbounds=False)
lines = []
linemarkers = []
linewidths = []
for info, shape in zip(m.alcapadifaults_info, m.alcapadifaults):
    if info["fault_type"] == 1:
        linemarkers.append('solid')
        linewidths.append(0.8)
    elif info["fault_type"] == 2:
        linemarkers.append('solid')
        linewidths.append(0.4)
    else:
        linemarkers.append('dashed')
        linewidths.append(0.8)
    lines.append(np.array(shape))
ax.add_collection(LineCollection(lines,linewidths=linewidths,linestyles=linemarkers,colors='red'))

m.drawcoastlines(linewidth=0.7)
m.drawcountries(linewidth=0.5)
parallels = np.arange(40,52,1)
# labels = [left,right,top,bottom]
m.drawparallels(parallels,labels=[True,False,False,False],color='grey',linewidth=0.25)
meridians = np.arange(0.,28,2)
m.drawmeridians(meridians,labels=[False,False,False,True],color='grey',linewidth=0.25)

plt.savefig("tectonicmap_alcapadi.pdf",bbox_inches='tight')
plt.show()
