#!/usr/bin/env python2
# -*- coding: utf-8 -*-
"""
Created on Wed Mar 28 11:12:51 2018

@author: emanuel
"""

import numpy as np
import matplotlib.pyplot as plt
from matplotlib.collections import PatchCollection,LineCollection
from mpl_toolkits.basemap import Basemap
from matplotlib.patches import PathPatch
from matplotlib.path import Path
from scipy.io.netcdf import netcdf_file
from scipy.interpolate import interp1d
import gdal


lat_0 = 46.5
lon_0 = 16
lat_1 = 44
lat_2 = 48
m = Basemap(projection='lcc',lat_0=46.5,lon_0=16,lat_1=38,lat_2=48,
            rsphere=(6378137.00,6356752.3142),resolution='i',
            width=1900000,height=1150000)

# load topographic data
lon1 = 0
lat1 = 39
lon2 = 31
lat2 = 52
topo = netcdf_file('../../../../PLOTS/ETOPO1_Ice_g_gmt4.grd','r')
tlons = topo.variables['x'][:] # Latitude values in netCDF file
tlats = topo.variables['y'][:] # Longitude ...
elev= topo.variables['z'][:]
# select subset
latidx = np.where((tlats>=lat1)*(tlats<=lat2))[0]
lonidx = np.where((tlons>=lon1)*(tlons<=lon2))[0]
tlats = tlats[latidx]
tlons = tlons[lonidx]
elev = elev[min(latidx):max(latidx)+1,min(lonidx):max(lonidx)+1]
# transform to nx x ny regularly spaced native projection grid
nx = int((m.xmax-m.xmin)/1000.)+1; ny = int((m.ymax-m.ymin)/1000.)+1
topodat,x,y = m.transform_scalar(elev,tlons,tlats,nx,ny,returnxy=True)


source_ds = gdal.Open("../../../../PLOTS/ETOPO1_Ice_g_gmt4.grd")
# crop to subset (not necessary, but a bit faster)
source_ds_cropped = gdal.Translate('',source_ds,projWin = [lon1,lat2,lon2,lat1],format='MEM')
# create hillshade and store in memory
hillshade = gdal.DEMProcessing('',source_ds_cropped,'hillshade',azimuth=315,altitude=45,
                               scale=111190,zFactor=10,format='MEM')
# brightness values as integer values
hillshade = hillshade.ReadAsArray()
# transform to nx x ny regularly spaced native projection grid
nx = int((m.xmax-m.xmin)/1000.)+1; ny = int((m.ymax-m.ymin)/1000.)+1
hillshade,x,y = m.transform_scalar(hillshade[::-1],tlons,tlats,nx,ny,returnxy=True)

# hillshade as transparency
contrast = 0 # 15 percent more contrast
hillshade[hillshade>np.max(hillshade)*(1-contrast/100)] = np.max(hillshade)*(1-contrast/100)
hillshade_rgba = np.zeros(np.shape(hillshade)+(4,))
contrastfu = interp1d(np.linspace(np.min(hillshade),np.max(hillshade),2),np.linspace(0,1,2))
hillshade = contrastfu(hillshade)
brighten = 65 # 15 percent brighter
brigthenfu = interp1d(np.linspace(0,1,2),np.linspace(0+brighten/100,1,2))
hillshade = brigthenfu(hillshade)

# transparancy is maximum where brightness is minimum
hillshade_rgba[:,:,-1] = 1-hillshade


f = plt.figure(figsize=(10,8))
ax = f.add_subplot(111)
im = m.imshow(hillshade_rgba,zorder=2)

m.readshapefile("../shape_files/tect_units_alcapadi","alcapadiunits",drawbounds=False)
patches   = []
colors = []
for i in range(len(m.alcapadiunits)):
    info = m.alcapadiunits_info[i]
    shape = m.alcapadiunits[i] 
    if info["RINGNUM"] == 1:
        pathcoords = np.zeros((0,2))
        pathcommands = []
        if info["tect_unit"] == "Adria accreted":
            colors.append((0.8,0.7,0.45)) #rgb value
        elif info["tect_unit"] == "Adria autochton":
            colors.append((0.52,0.32,0.2))
        elif info["tect_unit"] == "Europe accreted":
            colors.append((0.42,0.67,0.88))
        elif info["tect_unit"] == "flexural foredeep and graben fill":
            colors.append(0.6) # grayscale
        elif info["tect_unit"] == "Alpine Tethys":
            colors.append((0.,0.65,0.3))
        elif info["tect_unit"] == "Neotethys":
            colors.append((0.5,0.8,0.32))
        else:
            colors.append("lightgrey")
    pathcoords = np.vstack((pathcoords,np.array(shape)))
    pathcoords = np.vstack((pathcoords,np.zeros((1,2))))
    path_n = len(shape)*[Path.LINETO]
    path_n[0] = Path.MOVETO
    path_n.append(Path.CLOSEPOLY)
    pathcommands += path_n
    if i+1 == len(m.alcapadiunits):      
        path = Path(pathcoords,pathcommands)
        patch = PathPatch(path)
        patches.append(patch) 
        continue
    if m.alcapadiunits_info[i+1]["RINGNUM"] <= info["RINGNUM"]:
        path = Path(pathcoords,pathcommands)
        patch = PathPatch(path)
        patches.append(patch)
ax.add_collection(PatchCollection(patches, facecolor=colors, edgecolor='black', linewidths=0.3, zorder=2))

m.readshapefile("../shape_files/faults_alcapadi","alcapadifaults",drawbounds=False)
lines = []
linemarkers = []
linewidths = []
for info, shape in zip(m.alcapadifaults_info, m.alcapadifaults):
    if info["fault_type"] == 1:
        linemarkers.append('solid')
        linewidths.append(0.8)
    elif info["fault_type"] == 2:
        linemarkers.append('solid')
        linewidths.append(0.5)
    else:
        linemarkers.append('dashed')
        linewidths.append(0.8)
    lines.append(np.array(shape))
ax.add_collection(LineCollection(lines,linewidths=linewidths,linestyles=linemarkers,colors='red'))


if True:
    maptitle = "alcapadi_lambert_conformal.pdf"
    m.drawcoastlines(linewidth=0.5,color='grey')
    m.drawcountries(linewidth=0.3,color='grey')
    parallels = np.arange(40,52,1)
    paral = m.drawparallels(parallels,labels=[True,True,False,False],color='grey',linewidth=0.25)
    meridians = np.arange(0.,30,2)
    merid = m.drawmeridians(meridians,labels=[False,False,True,True],color='grey',linewidth=0.25)
    for pa in paral:
        for i in range(4):
            try:
                txt = paral[pa][1][i].get_text()
                paral[pa][1][i].set_text(txt[:-1])
            except:
                pass
    for me in merid:
        for i in range(4):
            try:
                txt = merid[me][1][i].get_text()
                merid[me][1][i].set_text(txt[:-1])
            except:
                pass

else:
    maptitle = "alcapadi_lambert_conformal_gridlines.pdf"
    parallels = np.arange(40,52,0.5)
    m.drawparallels(parallels,labels=[False,False,False,False],color='blue',dashes=(None,None),linewidth=0.3,zorder=3)
    meridians = np.arange(0.,29,0.5)
    m.drawmeridians(meridians,labels=[False,False,False,False],color='blue',dashes=(None,None),linewidth=0.3,zorder=3)
    
    parallels = np.arange(40,52,0.1)
    m.drawparallels(parallels,labels=[False,False,False,False],color='blue',dashes=(None,None),linewidth=0.05,zorder=3)
    meridians = np.arange(0.,29,0.1)
    m.drawmeridians(meridians,labels=[False,False,False,False],color='blue',dashes=(None,None),linewidth=0.05,zorder=3)
    
    parallels = np.arange(40,52,1)
    # labels = [left,right,top,bottom]
    paral = m.drawparallels(parallels,labels=[True,True,False,False],color='black',dashes=(None,None),linewidth=0.4,zorder=3)
    meridians = np.arange(0.,29,1)
    merid = m.drawmeridians(meridians,labels=[False,False,True,True],color='black',dashes=(None,None),linewidth=0.4,zorder=3)
    for pa in paral:
        for i in range(4):
            try:
                txt = paral[pa][1][i].get_text()
                paral[pa][1][i].set_text(txt[:-1])
            except:
                pass
    for me in merid:
        for i in range(4):
            try:
                txt = merid[me][1][i].get_text()
                merid[me][1][i].set_text(txt[:-1])
            except:
                pass
plt.text(0.75,0.98,"Lambert Conformal lat0/lon0=46.5/16 lat1/lat2=44/48",fontsize=5,transform = ax.transAxes)


axlegend = f.add_axes([0.125,0.01,0.1,0.1])
axlegend.axis('off')
#from matplotlib.patches import Rectangle
#ax.add_patch(Rectangle((0,-1), 5, 5,facecolor='green',transform = ax.transAxes))
plt.savefig(maptitle,dpi=300,bbox_inches='tight')
plt.savefig(maptitle.replace("pdf","png"),dpi=300,bbox_inches='tight')

plt.show()

#%%
from PyPDF2 import PdfFileReader, PdfFileWriter
map = PdfFileReader(maptitle)
legend = PdfFileReader("legend.pdf")
map = map.getPage(0)
map.mergeScaledTranslatedPage(legend.getPage(0),0.49,35,10)
writer = PdfFileWriter()
writer.addPage(map)
with open(maptitle,"wb") as outfile:
    writer.write(outfile)
