#!/usr/bin/env python2
# -*- coding: utf-8 -*-
"""
Created on Wed Mar 28 11:12:51 2018

@author: emanuel
"""

import numpy as np
import matplotlib.pyplot as plt
from matplotlib.collections import PatchCollection,LineCollection
from mpl_toolkits.basemap import Basemap
from matplotlib.patches import PathPatch
from matplotlib.path import Path
   
f = plt.figure(figsize=(10,8))
ax = f.add_subplot(111)
m = Basemap(projection='merc', llcrnrlat=43.6, urcrnrlat=48.5,
            llcrnrlon=5,urcrnrlon=17, resolution='i')

m.drawmapboundary(fill_color='aqua')
m.fillcontinents(color='lightgrey')

# Shapefiles can be read directly with the basemap toolbox
m.readshapefile("../shape_files/tect_units_schmid_2004","schmidunits",drawbounds=False)
patches   = []
colors = []
for i in range(len(m.schmidunits)):
    info = m.schmidunits_info[i]
    shape = m.schmidunits[i] 
    if info["RINGNUM"] == 1:
        pathcoords = np.zeros((0,2))
        pathcommands = []
        colors.append(info["hex_color"])
    pathcoords = np.vstack((pathcoords,np.array(shape)))
    pathcoords = np.vstack((pathcoords,np.zeros((1,2))))
    path_n = len(shape)*[Path.LINETO]
    path_n[0] = Path.MOVETO
    path_n.append(Path.CLOSEPOLY)
    pathcommands += path_n
    if i+1 == len(m.schmidunits):      
        path = Path(pathcoords,pathcommands)
        patch = PathPatch(path)
        patches.append(patch) 
        continue
    if m.schmidunits_info[i+1]["RINGNUM"] <= info["RINGNUM"]:
        path = Path(pathcoords,pathcommands)
        patch = PathPatch(path)
        patches.append(patch)
ax.add_collection(PatchCollection(patches, facecolor=colors, edgecolor='black', linewidths=0.1, zorder=2))

m.readshapefile("../shape_files/faults_schmid_2004","schmidfaults",drawbounds=False)
lines = []
linemarkers = []
for info, shape in zip(m.schmidfaults_info, m.schmidfaults):
    if info["fault_type"] == 1 or info["fault_type"] == 3:
        linemarkers.append('solid')
    else:
        linemarkers.append('dashed')
    lines.append(np.array(shape))
ax.add_collection(LineCollection(lines,linewidths=0.8,linestyles=linemarkers,colors='red'))

m.drawcoastlines(linewidth=0.7)
m.drawcountries(linewidth=0.5)
parallels = np.arange(40,50,1)
# labels = [left,right,top,bottom]
m.drawparallels(parallels,labels=[True,False,False,False],color='grey',linewidth=0.25)
meridians = np.arange(0.,20,1)
m.drawmeridians(meridians,labels=[False,False,False,True],color='grey',linewidth=0.25)


plt.savefig("tectonicmap_schmid_2004.pdf",bbox_inches='tight')
plt.show()